==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/DefaultCustomerTreeFlavors.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.customertreeflavors.TreeFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of customerTreeFlavors.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultCustomerTreeFlavors extends InnerModelObject implements CustomerTreeFlavors {
    protected List<TreeFlavor> treeFlavor;

    @Override
    public List<TreeFlavor> treeFlavor() {
        return treeFlavor;
    }

    @Override
    public void treeFlavor(List<TreeFlavor> treeFlavor) {
        this.treeFlavor = treeFlavor;
    }

    @Override
    public void addToTreeFlavor(TreeFlavor addTo) {
        if (treeFlavor == null) {
            treeFlavor = new ArrayList<>();
        }
        treeFlavor.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(treeFlavor);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultCustomerTreeFlavors) {
            DefaultCustomerTreeFlavors other = (DefaultCustomerTreeFlavors) obj;
            return
                Objects.equals(treeFlavor, other.treeFlavor);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("treeFlavor=" + treeFlavor)
            .toString();
    }


    /**
     * Creates an instance of defaultCustomerTreeFlavors.
     */
    public DefaultCustomerTreeFlavors() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/DefaultCustomerTreeFlavors.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.customertreeflavors.TreeFlavor;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of customerTreeFlavors.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultCustomerTreeFlavors extends InnerModelObject implements CustomerTreeFlavors {
    protected List<TreeFlavor> treeFlavor;

    @Override
    public List<TreeFlavor> treeFlavor() {
        return treeFlavor;
    }

    @Override
    public void treeFlavor(List<TreeFlavor> treeFlavor) {
        this.treeFlavor = treeFlavor;
    }

    @Override
    public void addToTreeFlavor(TreeFlavor addTo) {
        if (treeFlavor == null) {
            treeFlavor = new ArrayList<>();
        }
        treeFlavor.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(treeFlavor);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultCustomerTreeFlavors) {
            DefaultCustomerTreeFlavors other = (DefaultCustomerTreeFlavors) obj;
            return
                Objects.deepEquals(treeFlavor, other.treeFlavor);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("treeFlavor=" + treeFlavor)
            .toString();
    }


    /**
     * Creates an instance of defaultCustomerTreeFlavors.
     */
    public DefaultCustomerTreeFlavors() {
    }

}
